/*
	@name Blinky
	     STM32VLDISCOVERY
	  GPIO PC8  PC9   CMSYS
*/
#include "stm32f10x.h"

void InitGPIO(void)
{
   RCC->APB2ENR	|= RCC_APB2ENR_IOPCEN;		//    .     . 
											//   STM32 =)))        
   GPIOC->CRH	&= ~GPIO_CRH_CNF9;			//   CNF3 ..      (01)
											//  Open Drain.    Push-Pull (00)
 
   GPIOC->CRH   |= GPIO_CRH_MODE9_0;		//     (    , 
											//  GPIOA-CRL-MODE    (00).     
											//         . 
											//   18  RM
   GPIOC->CRH	&= ~GPIO_CRH_CNF8;
   GPIOC->CRH   |= GPIO_CRH_MODE8_0;
}

/*----------------------------------------------------------------------------
  TIM2 Init procedte -> set timer as counter with autoreload; time = 1sec
 *----------------------------------------------------------------------------*/
void InitTmr2 (void)
{
  RCC->APB1ENR	|= (uint32_t)RCC_APB1ENR_TIM2EN;		//    

  TIM2->ARR = 10000;						//    10000 
  TIM2->PSC = 2399;							//   ->   = SysClc/2400
  TIM2->CR1 &= (uint16_t)~TIM_CR1_CKD;		//   = 1
  /* Generate an update event to reload the Prescaler value immediatly */
  TIM2->EGR	= ((uint16_t)0x0001);
  /* TIM2 enable counter */
  TIM2->CR1 |= (uint32_t)TIM_CR1_CEN;		//  
  /* Enable the Interrupt sources */
  TIM2->DIER |= TIM_DIER_UIE;				//    
  /* Clear TIM2 update interrupt flag */
  TIM2->SR = (uint16_t)~TIM_SR_UIF;

  /* In DEBUG Mode Stop the Timer2 */
  // DBGMCU->CR |= DBGMCU_TIM2_STOP; 
}

/*----------------------------------------------------------------------------
  TIM2 NVIC enable Interrupt
 *----------------------------------------------------------------------------*/
void InitNVIC(void)
{
  /*   TIM2   28 .       
     (  0) "Set Enable Register" ->   28-  */ 
  NVIC->ISER[0] |= NVIC_ICER_CLRENA_28;

}

 /*----------------------------------------------------------------------------
  TIM2 Interrupt Handler
 *----------------------------------------------------------------------------*/
void TIM2_IRQHandler(void)
{
  static int Led = 0x00000000;

  /* Clear TIM2 update interrupt flag */
  TIM2->SR = (uint16_t)~TIM_SR_UIF;
  if (Led) 
     {
	   GPIOC->BSRR =GPIO_BSRR_BR8;
	   GPIOC->BSRR =GPIO_BSRR_BS9;
       Led = 0x00000000;
	 }
     else     
	 {
	   GPIOC->BSRR =GPIO_BSRR_BR9;
	   GPIOC->BSRR =GPIO_BSRR_BS8;
	   Led = 0x00000001;
	 }
}

int main(void)
{
  InitGPIO();
  InitNVIC();
  InitTmr2();
  
while(1)
	{

	}
} 


